import{_ as e,n as l,s,x as a}from"./index-Bt5Cdm1t.js";import"./c.CyL_D25b.js";import"./c.BU1vbuah.js";let o=class extends s{render(){return a`
      <esphome-process-dialog
        heading="Clean All"
        .type=${"clean-all"}
        .spawnParams=${{clean_build_dir:!0}}
        @closed=${this._handleClose}
      ></esphome-process-dialog>
    `}_handleClose(){this.parentNode.removeChild(this)}};o=e([l("esphome-clean-all-dialog")],o);
//# sourceMappingURL=c.D7SdLOTV.js.map
